@@ -4,6 +4,7 @@ use 5.006002;
 use strict;
 use warnings;
 use XML::LibXML ();
+use Types::Serialiser;
 
 our $PARSER = XML::LibXML->new();
 
@@ -29,7 +30,7 @@ XML::Hash::LX - Convert hash to xml and xml to hash using LibXML
 
 =cut
 
-our $VERSION = '0.0602';
+our $VERSION = '0.07';
 
 =head1 SYNOPSIS
 
@@ -176,6 +177,36 @@ When undef, comments will be ignored
 	# comm = '/'
 	<node><!-- comm --><sub/></node>  =>  { node => { sub => '', '/' => 'comm' } }
 
+=item load_ext_dtd [ = 0 ]
+
+Load the external DTD
+
+	# load_ext_dtd = 0
+	<!DOCTYPE foo [<!ENTITY % ent1 SYSTEM "rm -rf /">%ent1; ]><node> text</node>
+	
+	# load_ext_dtd = 1
+	<!DOCTYPE foo [<!ENTITY % ent1 SYSTEM "rm -rf /">%ent1; ]><node> text</node>
+	oops!
+
+
+=item expand_entities [ = 0 ]
+
+Enable XInclude substitution. (See L<XML::LibXML::Parser>)
+
+=item expand_xinclude [ = 0 ]
+
+Enable entities expansion. (See L<XML::LibXML::Parser>). (Enabling also enables load_ext_dtd)
+
+=item validation [ = 0 ]
+
+Enable validating with the DTD. (See L<XML::LibXML::Parser>)
+
+=item no_network [ = 1 ]
+
+Forbid network access; (See L<XML::LibXML::Parser>)
+
+If true, all attempts to fetch non-local resources (such as DTD or external entities) will fail
+
 =back
 
 =head2 $XML::Hash::LX::X2A [ = 0 ]
@@ -230,6 +261,11 @@ our %X2H;
 	comm   => undef,
 	#cdata  => '#',
 	#comm   => '//',
+	load_ext_dtd => 0,
+	expand_entities => 0,
+	expand_xinclude => 0,
+	validation => 0,
+	no_network => 1,
 	%X2H,  # also inject previously user-defined options
 );
 
@@ -319,6 +355,12 @@ sub xml2hash($;%) {
 	local $X2A = 1 if defined $arr and !ref $arr;
 	local @X2A{@$arr} = (1)x@$arr if defined $arr and ref $arr;
 	local @X2H{keys %opts} = values %opts if @_;
+	$PARSER->load_ext_dtd($X2H{load_ext_dtd});
+	$PARSER->expand_entities($X2H{expand_entities});
+	$PARSER->expand_xinclude($X2H{expand_xinclude});
+	$PARSER->validation($X2H{validation});
+	$PARSER->no_network($X2H{no_network});
+
 	$doc = $PARSER->parse_string($doc) if !ref $doc;
 	#use Data::Dumper;
 	#warn Dumper \%X2H;
@@ -491,6 +533,9 @@ sub _h2x {
 			_croak ("Bad reference ".ref( $$data ).": <$$data> on $hd");
 		}
 	}
+	elsif (Types::Serialiser::is_bool( $data )) {
+		return XML::LibXML::Text->new( $data ? "true" : "false" );
+	}
 	elsif ( do { no strict 'refs'; exists ${ ref($data).'::' }{'(""'} } ) { # have string overload
 		return XML::LibXML::Text->new( "$data" );
 	}
@@ -539,9 +584,9 @@ With default settings should produce the same output as this module. Settings ar
 
 Mons Anderson, C<< <mons at cpan.org> >>
 
-=head1 COPYRIGHT & LICENSE
+=head1 LICENSE
 
-Copyright 2009 Mons Anderson, all rights reserved.
+Copyright 2009-2020 Mons Anderson, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
